@@ -86,7 +86,7 @@
 #define KCOREADDONS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCOREADDONS_NO_DEPRECATED
-#  define KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55400
+#  define KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55800
 #endif
 #ifdef KCOREADDONS_NO_DEPRECATED_WARNINGS
 #  define KCOREADDONS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE 0x55400
+#    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE 0x55800
 #  endif
 #endif
 
@@ -181,6 +181,30 @@
 #else
 #  define KCOREADDONS_DEPRECATED_VERSION_5_80(text)
 #endif
+
+#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x55400
+#  define KCOREADDONS_DEPRECATED_VERSION_5_84(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCOREADDONS_DEPRECATED_VERSION_5_84(text)
+#endif
+
+#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x55600
+#  define KCOREADDONS_DEPRECATED_VERSION_5_86(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCOREADDONS_DEPRECATED_VERSION_5_86(text)
+#endif
+
+#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x55700
+#  define KCOREADDONS_DEPRECATED_VERSION_5_87(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCOREADDONS_DEPRECATED_VERSION_5_87(text)
+#endif
+
+#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x55800
+#  define KCOREADDONS_DEPRECATED_VERSION_5_88(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCOREADDONS_DEPRECATED_VERSION_5_88(text)
+#endif
 #define KCOREADDONS_DEPRECATED_VERSION_4(minor, text)      KCOREADDONS_DEPRECATED_VERSION_4_##minor(text)
 #define KCOREADDONS_DEPRECATED_VERSION_5(minor, text)      KCOREADDONS_DEPRECATED_VERSION_5_##minor(text)
 #define KCOREADDONS_DEPRECATED_VERSION(major, minor, text) KCOREADDONS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
@@ -247,7 +271,7 @@
 #define KCOREADDONS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCOREADDONS_NO_DEPRECATED
-#  define KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55400
+#  define KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55800
 #endif
 #ifdef KCOREADDONS_NO_DEPRECATED_WARNINGS
 #  define KCOREADDONS_DEPRECATED_WARNINGS_SINCE 0
@@ -257,7 +281,7 @@
 #  ifdef KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE 0x55400
+#    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE 0x55800
 #  endif
 #endif
 
@@ -342,6 +366,30 @@
 #else
 #  define KCOREADDONS_DEPRECATED_VERSION_5_80(text)
 #endif
+
+#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x55400
+#  define KCOREADDONS_DEPRECATED_VERSION_5_84(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCOREADDONS_DEPRECATED_VERSION_5_84(text)
+#endif
+
+#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x55600
+#  define KCOREADDONS_DEPRECATED_VERSION_5_86(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCOREADDONS_DEPRECATED_VERSION_5_86(text)
+#endif
+
+#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x55700
+#  define KCOREADDONS_DEPRECATED_VERSION_5_87(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCOREADDONS_DEPRECATED_VERSION_5_87(text)
+#endif
+
+#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x55800
+#  define KCOREADDONS_DEPRECATED_VERSION_5_88(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCOREADDONS_DEPRECATED_VERSION_5_88(text)
+#endif
 #define KCOREADDONS_DEPRECATED_VERSION_4(minor, text)      KCOREADDONS_DEPRECATED_VERSION_4_##minor(text)
 #define KCOREADDONS_DEPRECATED_VERSION_5(minor, text)      KCOREADDONS_DEPRECATED_VERSION_5_##minor(text)
 #define KCOREADDONS_DEPRECATED_VERSION(major, minor, text) KCOREADDONS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
